package handler

import (
	"GtDataStore/app/cmd/organization/internal/logic/job"
	"GtDataStore/app/cmd/organization/internal/svc"
	"GtDataStore/app/model"
	"context"
	"github.com/zeromicro/go-zero/core/logx"
	"time"
)

func DeviceChest(ctx context.Context, task *job.Task, technologyName string) error {
	// 1. 查询所有的设备
	devices, err := findDeviceChest(task.Job.SvcCtx, int64(task.Id))
	if err != nil {
		return err
	}
	// 2. 获得点位信息
	//var wg sync.WaitGroup
	//wg.Add(len(devices))
	//for _, device := range devices {
	//	device := device
	//	go func() {
	//		defer wg.Done()
	//		if err := device.Items.FillCurrentValue(); err != nil {
	//			logx.Errorf("DeviceChest device.Items.FillCurrentValue error: %s", err.Error())
	//		}
	//	}()
	//}
	//
	//wg.Wait()

	// 3. 转换为存储对象
	workings, err := transDeviceChestData(devices)
	if err != nil {
		return err
	}
	// 4. 批量入库
	if _, err := task.Job.SvcCtx.WorkingChest.MultiInsert(context.Background(), workings); err != nil {
		logx.Errorf("DeviceChest task.Job.SvcCtx.WorkingChest.MultiInsert error: %s", err.Error())
	}

	return nil
}

func findDeviceChest(svcCtx *svc.ServiceContext, projectId int64) ([]model.DcDeviceBind, error) {
	if data := deviceBindCacheTable.GetCache(DEVICE_CHEST); data != nil {
		return data, nil
	}
	if devices, err := svcCtx.DeviceBind.FindByProjectIdDeviceType(context.Background(), projectId, DEVICE_CHEST); err != nil {
		logx.Infof("findDeviceChest not found devices")
		return nil, err
	} else {
		deviceBindCacheTable.SetCache(DEVICE_CHEST, devices, time.Now().Add(300*time.Second))
		return devices, nil
	}
}

func transDeviceChestData(datas []model.DcDeviceBind) ([]model.DcWorkingChest, error) {
	ts := make([]model.DcWorkingChest, len(datas))

	for i, data := range datas {
		ts[i] = model.DcWorkingChest{
			Id:                  0,
			ProjectId:           data.ProjectId,
			DeviceCode:          data.DeviceCode,
			Switch:              data.Items.GetItemInt64Value("switch"),
			Level:               data.Items.GetItemFloat64Value("level"),
			AgitatorStatus:      data.Items.GetItemInt64Value("agitator_status"),
			AgitatorDuration:    data.Items.GetItemInt64Value("agitator_duration"),
			AgitatorFaultStatus: data.Items.GetItemInt64Value("agitator_fault_status"),
			CTime:               time.Now(),
		}
	}

	return ts, nil
}
