package model

import (
	"context"
	"fmt"
	"github.com/zeromicro/go-zero/core/stores/sqlc"
	"github.com/zeromicro/go-zero/core/stores/sqlx"
)

var _ DcWorkingRoModel = (*customDcWorkingRoModel)(nil)

type (
	// DcWorkingRoModel is an interface to be customized, add more methods here,
	// and implement the added methods in customDcWorkingRoModel.
	DcWorkingRoModel interface {
		dcWorkingRoModel
		FindOneByCode(ctx context.Context, projectId int64, deviceCode string) (*DcWorkingRo, error)
	}

	customDcWorkingRoModel struct {
		*defaultDcWorkingRoModel
	}
)

// NewDcWorkingRoModel returns a model for the database table.
func NewDcWorkingRoModel(conn sqlx.SqlConn) DcWorkingRoModel {
	return &customDcWorkingRoModel{
		defaultDcWorkingRoModel: newDcWorkingRoModel(conn),
	}
}

func (m *defaultDcWorkingRoModel) FindOneByCode(ctx context.Context, projectId int64, deviceCode string) (*DcWorkingRo, error) {
	var resp DcWorkingRo
	query := fmt.Sprintf("select %s from %s where `project_id` = ? and `device_code` = ? order by c_time desc limit 1", dcWorkingRoRows, m.table)
	err := m.conn.QueryRowCtx(ctx, &resp, query, projectId, deviceCode)
	switch err {
	case nil:
		return &resp, nil
	case sqlc.ErrNotFound:
		return nil, ErrNotFound
	default:
		return nil, err
	}
}
